#!/bin/sh

# Simple shell-based filter. It is meant to be invoked as follows:
#       /path/to/script -f sender recipients...

# Localize these. The -G option does nothing before Postfix 2.3.
INSPECT_DIR=/var/spool/gpgit
SENDMAIL="/usr/sbin/sendmail -G -i" # NEVER NEVER NEVER use "-t" here.

# Exit codes from <sysexits.h>
EX_TEMPFAIL=75
EX_UNAVAILABLE=69

# Clean up when done or when aborting.
trap "rm -f in.$$" 0 1 2 3 15

# Start processing.
cd $INSPECT_DIR || {
echo $INSPECT_DIR does not exist; exit $EX_TEMPFAIL; }

cat >in.$$ || { 
echo Cannot save mail to file; exit $EX_TEMPFAIL; }

# Specify your content filter here.
# filter <in.$$ || {
#   echo Message content rejected; exit $EX_UNAVAILABLE; }

EXTRA_GI=""
NOTE="single users"
EXTRA_SM=""
RCPT=""
while [ "`echo $1 | sed -e 's/^\(.\).*/\1/'`" = "-" ]; do
	if [ "$1" = "-f" ]; then
		EXTRA_SM="$EXTRA_SM $1 $2"
		shift 2
	elif [ "$1" = "--target:exploder" ]; then
		EXTRA_GI="--skip-pubkey-check"
		NOTE="group found"
		shift
	elif [ "`echo $1 | sed -e 's/l-.*/l-/'`" = "--target:catchall-" ]; then
		EXTRA_GI="--skip-pubkey-check"
		NOTE="group found"
		RCPT="@`echo $1 | sed -e 's/^--target:catchall-//'`"
		shift
	elif [ "`echo $1 | sed -e 's/:.*/:/'`" = "--target:" ]; then
		shift
	else
		EXTRA_SM="$EXTRA_SM $1"
		shift
	fi
done
if [ "$RCPT" = "" ]; then
	RCPT="$@"
fi
#/usr/bin/logger -i -p mail.info -t gpgit "Processing message for ($EXTRA_GI / $EXTRA_SM) $RCPT"
/usr/bin/logger -i -p mail.info -t gpgit "Processing message for $RCPT ($NOTE)"
#/usr/bin/logger -i -p mail.info -t gpgit "IDs `id` Spool file `ls -l in.$$`"
/home/gpgit/gpgit.pl $EXTRA_GI $RCPT <in.$$ | $SENDMAIL $EXTRA_SM "$@"

exit $?
